<?php

abstract class OferteoApiUtils {
    public static function findCategoryInUrl($url, $urlPrefix, $categoriesMap) {
        $url = preg_replace('/^' . addcslashes($urlPrefix, '/') . '/', '', $url);
        $url = trim($url, '/');
        $url = explode('/', $url);

        $category = null;

        if (!empty($url) && array_key_exists('/' . $url[0], $categoriesMap)) {
            $category = '/' . $url[0];
        }

        return $category;
    }

    public static function findLocationInUrl($url, $urlPrefix, $locationsMap) {
        $url = preg_replace('/^' . addcslashes($urlPrefix, '/') . '/', '', $url);
        $url = trim($url, '/');
        $url = explode('/', $url);

        $location = null;

        if (!empty($url)) {
            if (array_key_exists('/' . $url[0], $locationsMap)) {
                $location = '/' . $url[0];
            } elseif (count($url) > 1 && array_key_exists('/' . $url[1], $locationsMap)) {
                $location = '/' . $url[1];
            }
        }

        return $location;
    }

    public static function findRfpIdInUrl($url) {
        $rfpId = -1;

        if ($url) {
            if (preg_match('/^(.*)\/([a-zA-Z0-9-]+)-([0-9-]+)$/', $url, $matches)) {
                if (count($matches) >= 4 && $matches[3]) {
                    $rfpId = intval($matches[3]);
                }
            }
        }

        return $rfpId;
    }

    public static function findPagerInUrl($requestedUrl) {
        $pager = -1;

        $requestedUrl = explode('?', $requestedUrl);
        $requestedUrl = explode('/', $requestedUrl[0]);

        $lastParam = $requestedUrl[count($requestedUrl) - 1];

        if (preg_match('/^([0-9]+)$/', $lastParam)) {
            $pager = intval($lastParam);
        }

        return $pager;
    }

    public static function getSortFromUrl($urlQueryString) {
        $params = array();

        parse_str($urlQueryString, $params);

        return isset($params['sort']) && $params['sort'] ? 1 : 0;
    }

    public static function getRfpListHeaderPd($categoryName = null, $locationName = null, $districtName = null, $defaultTitle = '') {
        $result = '';
		$added = false;

		if ($categoryName != null && trim($categoryName) != '') {
            $categoryCapitalize = self::toUpperFirstLetters($categoryName);
			$result .= $categoryCapitalize;
			$added = true;
		}

		if ($districtName != null && trim($districtName) != '') {
            $districtTmp = $districtName;
			if ($districtTmp != null) {
                if ($added) {
                    $result .= ' ';
                }
                $result .= $districtName . ' ';
            }
		} else {
            if ($locationName != null && trim($locationName) != '') {
                if ($added) {
                    $result .= ' ';
                } else {
                    $result .= $defaultTitle . ' ';
                }
                $locCapitalize = self::toUpperFirstLetters($locationName);
				$result .= $locCapitalize;
				$added = true;
			}
        }

		if ($added == false) {
            $result .= $defaultTitle;
        }
		return trim($result);
    }

    private static function toUpperFirstLetters($inString, $delimeter = ' ', $onlyfirstWord = false, $capitalizeOneLetter = false) {
        $result = explode($delimeter, $inString);

        $count = $onlyfirstWord ? 1 : count($result);

        for ($i = 0; $i < $count; $i++) {
            $tmp = ucfirst($result[$i]);

            if ($capitalizeOneLetter) {
                $tmp = mb_substr($tmp, 0, 1, 'UTF-8') . mb_strtolower(mb_substr($tmp, 1, null, 'UTF-8'), 'UTF-8');
            }

            $result[$i] = $tmp;
        }

        return join($delimeter, $result);
    }

    public static function changeSuffix($inputText, $number, $endings = array('', '', '')) {
        if ($number == 1) {
            $result = $inputText . $endings[0];
        } else {
            $lastDigit = $number % 10;
            $mod100 = $number % 100;

            if (($lastDigit > 1 && $lastDigit < 5) && !($number > 10 && $number < 20) && !($mod100 > 10 && $mod100 < 20)) {
                $result = $inputText . $endings[1]; // komentarze
            } else {
                $result = $inputText . $endings[2];  // komentarzy
            }
        }

        return $result;
    }

    public static function getShortedText($text, $length = 0) {
        if ($text) {
            $chars = array('.', ',', ':', ';', ')', '}', ']', '/', '?', '-');

            $text = trim($text);

            foreach ($chars as $char) {
                $text = ltrim($text, $char);
            }

            $text = trim($text);

            if ($length && mb_strlen($text, 'UTF-8') >= $length) {
                $text = mb_substr($text, 0, $length, 'UTF-8');
            }
        }

        return $text;
    }
}