<?php

class RfpHtmlBuilder {

    private $rfp;
    private $urlPrefix;
    private $locale;
    private $currentUrl;
    private $html;

    public function __construct($rfp, $urlPrefix, $locale, $currentUrl) {
        $this->rfp = $rfp;
        $this->urlPrefix = $urlPrefix;
        $this->locale = $locale;
        $this->currentUrl = $currentUrl;
    }

    public function getHtml() {
        $this->html .= '<div class="infobox">';

            $this->html .= '<div class="info-header">';
                $this->html .= '<span>' . OferteoApiDict::get($this->locale, 'rfp.details.number') . $this->rfp->rfpId . '</span>';
                $this->html .= '<a class="btn btn-success" title="'
                    . $this->rfp->categoryName . ' - ' . OferteoApiDict::get($this->locale, 'rfp.details.button.add.rfp.title') . '" href="'
                    . $this->rfp->formUrl .'">' . OferteoApiDict::get($this->locale, 'rfp.details.button.add.rfp.anchor') . '</a>';
                $this->html .= '<div class="clear"></div>';
                $this->html .= '<h1>' . $this->rfp->title . '</h1>';
            $this->html .= '</div>';

            $this->html .= '<div class="line-grey"></div>';

            $this->html .= '<div class="info-main">';
                $this->html .= '<div class="info-main-data">';
                    $this->html .= '<div class="info-main-data-label">' . OferteoApiDict::get($this->locale, 'rfp.details.category') . '</div>';
                    $this->html .= '<div class="info-main-data-value">' . $this->rfp->categoryName . '</div>';

                    if ($this->rfp->srcCountry) {
                        $this->html .= '<div class="info-main-data-label">' . OferteoApiDict::get($this->locale, 'rfp.details.src.country') . '</div>';
                        $this->html .= '<div class="info-main-data-value">'
                            . $this->rfp->srcCountry . '&nbsp;' . $this->rfp->srcCity . '</div>';
                    }

                    if ($this->rfp->dstCountry) {
                        $this->html .= '<div class="info-main-data-label">'
                            . ($this->rfp->srcCountry
                                ? OferteoApiDict::get($this->locale, 'rfp.details.dst.country')
                                : OferteoApiDict::get($this->locale, 'rfp.details.dst.region'))
                            . '</div>';
                        $this->html .= '<div class="info-main-data-value">'
                            . $this->rfp->dstCountry . '&nbsp;' . $this->rfp->dstVoivodship . '&nbsp;' . $this->rfp->dstCity . '</div>';
                    }

                    $this->html .= '<div class="info-main-data-label">' . OferteoApiDict::get($this->locale, 'rfp.details.subject') . '</div>';
                    if ($this->rfp->individual) {
                        if ($this->rfp->active) {
                            $iconCssClass = "icon-individual-person-active";
                        } else {
                            $iconCssClass ="icon-individual-person-inactive";
                        }
                    } else {
                        if ($this->rfp->active) {
                            $iconCssClass = "icon-company-active";
                        } else {
                            $iconCssClass = "icon-company-inactive";
                        }
                    }
                    $this->html .= '<div class="info-main-data-value">';
                    if ($this->rfp->individual) {
                        $this->html .= '<div class="icon-individual-person ' . $iconCssClass
                            . '" title="' . OferteoApiDict::get($this->locale, 'rfp.details.subject.person.title') . '"></div>'
                            . OferteoApiDict::get($this->locale, 'rfp.details.subject.person');
                    } else {
                        $this->html .= '<div class="icon-company ' . $iconCssClass
                            . '" title="' . OferteoApiDict::get($this->locale, 'rfp.details.subject.company.title') . '"></div>'
                            . OferteoApiDict::get($this->locale, 'rfp.details.subject.company');
                    }
                    $this->html .= '</div>';
                $this->html .= '</div>';

                $this->html .= '<div class="info-main-date">';
                    $this->html .= '<span>' . date('Y-m-d', floor($this->rfp->activationTime / 1000))
                        . OferteoApiDict::get($this->locale, 'rfp.search.rfp.fromTo') . date('Y-m-d', floor($this->rfp->expirationTime / 1000)) . '</span>';
                    $this->html .= '<br/><span>' . OferteoApiDict::get($this->locale, 'rfp.details.date.added') . $this->rfp->activationPeriod . '</span>';
                $this->html .= '</div>';

                $this->html .= '<div class="clear"></div>';

                $this->html .= '<div class="info-content">';
                    $this->html .= '<div class="info-content-text">'
                        . nl2br($this->rfp->description) . '</div>';

                    $this->html .= '<form style="display: inline;" method="post" action="'
                        . $this->rfp->uncoverUrl . '">'
                        . '<input type="hidden" name="doUncover" value="true">'
                        . '<input type="hidden" name="oc" value="PP_' . $this->rfp->oc . '">'
                        . '<input type="hidden" name="rfpId" value="' . $this->rfp->rfpId . '">'
                        . '<button type="submit" class="btn btn-primary">'
                            . OferteoApiDict::get($this->locale, 'rfp.details.button.uncover')
                        . '</button>'
                        . '</form>';

                    $this->html .= '<div class="clear"></div>';
                $this->html .= '</div>';

                $this->html .= '<div class="cta-link">'
                    . '<a href="' . $this->rfp->formUrl . '" title="'
                        . OferteoApiDict::get($this->locale, 'rfp.details.button.similar.title') . '">'
                        . OferteoApiDict::get($this->locale, 'rfp.details.button.similar.uncover') . '</a>'
                    . '</div>';

                $this->html .= '<div class="similar-offer">';
                    $this->html .= '<h2>' . OferteoApiDict::get($this->locale, 'rfp.details.similar.title') . '</h2>';

                    foreach ($this->rfp->similarRfps as $similarRfp) {
                        $this->html .= '<div class="similar-offer-title">';
                            $this->html .= '<a href="' . $this->urlPrefix . '/' . $similarRfp->rfpUrl . '" title="' . $similarRfp->title . '">'
                                . $similarRfp->title . '</a>';
                            $this->html .= '<span>' . $similarRfp->activationPeriod . '</span>';
                        $this->html .= '</div>';
                    }
                $this->html .= '</div>';
            $this->html .= '</div>';

        $this->html .= '</div>';

        return $this->html;
    }

}