<?php

class RfpsHtmlBuilder {

    public $rfpSearchResult;
    public $urlPrefix;
    public $locale;
    public $urlCurrent;
    public $selectedCategoryUrl;
    public $selectedLocationUrl;
    public $pageSize;
    public $sort;
    public $urlQueryString;

    public $html;

    public function __construct(
        $rfpSearchResult,
        $urlPrefix,
        $locale,
        $urlCurrent,
        $selectedCategoryUrl,
        $selectedLocationUrl,
        $pageSize,
        $sort,
        $urlQueryString
    ) {
        $this->rfpSearchResult = $rfpSearchResult;
        $this->urlPrefix = $urlPrefix;
        $this->locale = $locale;
        $this->urlCurrent = $urlCurrent;
        $this->selectedCategoryUrl = $selectedCategoryUrl;
        $this->selectedLocationUrl = $selectedLocationUrl;
        $this->pageSize = $pageSize;
        $this->sort = $sort;
        $this->urlQueryString = $urlQueryString;

        $this->html = '';
    }

    public function getHtml() {
        $this->html = '<h1>';
        $this->getRfpsListTitle(OferteoApiDict::get($this->locale, 'rfp.search.title.default'));
        $this->html .= '</h1>';

        $this->getAskForOfferHtml();

        $this->addMainLocations();

        if ($this->rfpSearchResult->rfpsCounter > 0) {
            $this->addSummary();

            foreach ($this->rfpSearchResult->rfps as $i => $rfp) {
                $this->addRfpElement($rfp, $i);
            }

            $this->getPaginationAndSortHtml();
        } else {
            $this->html .= '<div class="not-found-info">'
                . '<span>' . OferteoApiDict::get($this->locale, 'rfp.search.results.nodata') . '</span>'
                . '</div>';
        }

        return $this->html;
    }

    public function getRfpsListTitle($defaultText = '') {
        $this->html .= OferteoApiUtils::getRfpListHeaderPd(
            $this->rfpSearchResult->selectedCategoryName,
            $this->rfpSearchResult->selectedLocationName,
            null,
            $defaultText
        );
    }

    public function getAskForOfferHtml() {
        $this->html .= '<div class="cta-box">';

        $categoryUrl = $this->selectedCategoryUrl ? '/' . $this->selectedCategoryUrl . '/zapytanie' : '/zapytaj-o-oferte';

        $ocUrl = $this->rfpSearchResult->oc ? '?oc=PP_' . $this->rfpSearchResult->oc : '';

        $url = $this->rfpSearchResult->oferteoPrefixUrl . $categoryUrl . $ocUrl;

        $this->html .= '<a href="' . $url . '" class="btn btn-success">'
            . '<strong>' . OferteoApiDict::get($this->locale, 'rfp.search.newRfp') . '</strong>'
            . '<br/><span>' . OferteoApiDict::get($this->locale, 'rfp.search.newRfp.free') . '</span>'
            . '</a>';

        $this->html .= '<ul>'
            . '<li>' . OferteoApiDict::get($this->locale, 'rfp.search.newRfp.part1') . '</li>'
            . '<li>' . OferteoApiDict::get($this->locale, 'rfp.search.newRfp.part2') . '</li>'
            . '</ul>';

        $this->html .= '<div class="clear"></div>';

        $this->html .= '</div>';
    }

    public function addMainLocations() {
        $this->html .= '<div class="location-link">';

        $cities = array(
            'Cała Polska' => '/polska',
            'Warszawa' => '/warszawa',
            'Wrocław' => '/wroclaw',
            'Kraków' => '/krakow',
            'Poznań' => '/poznan',
            'Łódź' => '/lodz',
            'Gdańsk' => '/gdansk',
            'Szczecin' => '/szczecin',
            'Katowice' => '/katowice',
            'Bydgoszcz' => '/bydgoszcz',
            'Lublin' => '/lublin',
            'Bielsko-Biała' => '/bielsko-biala',
            'Częstochowa' => '/czestochowa',
            'Rzeszów' => '/rzeszow',
            'Białystok' => '/bialystok',
            'Gliwice' => '/gliwice',
            'Sosnowiec' => '/sosnowiec',
            'Kielce' => '/kielce',
            'Gdynia' => '/gdynia',
            'Toruń' => '/torun',
            'Radom' => '/radom'
        );

        $categoryUrl = $this->selectedCategoryUrl ? '/' . $this->selectedCategoryUrl : '';

        foreach ($cities as $cityName => $cityUrl) {
            $this->html .= '<a href="' . $this->urlPrefix . $categoryUrl . $cityUrl . '">'
                . $cityName . '</a>';
        }

        $this->html .= '</div>';
    }

    public function addSummary() {
        $this->html .= '<div class="information-box background-grey">';

        $this->html .= '<div class="customers-number"><h2>';

        $this->html .= $this->rfpSearchResult->rfpsCounter . '&nbsp;'
            . OferteoApiUtils::changeSuffix('Klient', $this->rfpSearchResult->rfpsCounter, array('', 'ów', 'ów'))
            . '&nbsp;na&nbsp;';

        $this->getRfpsListTitle();

        $this->html .= '</h2></div>';

        $this->addSortBox();

        $this->html .= '<div class="clear"></div>';

        $this->html .= '</div>';
    }

    public function addSortBox() {
        $this->html .= '<div class="sort-box">';

        $this->html .= '<strong>' . OferteoApiDict::get($this->locale, 'rfp.search.results.sort') . '</strong>';

        if ($this->sort == OferteoApi::DEFAULT_SORT) {
            $this->html .= '<span>' . OferteoApiDict::get($this->locale, 'rfp.search.results.sort.activation') . '</span>'
                . '<span class="separator">&nbsp;|&nbsp;</span>'
                . '<a href="' . $this->getUrlCurrentSelection() . '?sort=1">'
                . OferteoApiDict::get($this->locale, 'rfp.search.results.sort.expiry')
                . '</a>';
        } else {
            $this->html .= '<a href="' . $this->getUrlCurrentSelection() . '">'
                . OferteoApiDict::get($this->locale, 'rfp.search.results.sort.activation')
                . '</a>'
                . '<span class="separator">&nbsp;|&nbsp;</span>'
                . '<span>' . OferteoApiDict::get($this->locale, 'rfp.search.results.sort.expiry') . '</span>';
        }

        $this->html .= '</div>';
    }

    private function getUrlCurrentSelection() {
        $category = $this->selectedCategoryUrl != null ? $this->selectedCategoryUrl : "";
		$location = $this->selectedLocationUrl != null ? $this->selectedLocationUrl : "";
		return $this->urlPrefix . $category . $location;
    }

    public function addRfpElement($rfp, $i) {
        $this->html .= '<div class="item' . ($i % 2 ? ' background-grey' : '') . '">';

        $this->html .= '<div class="item-panel-left">';
        $this->addLeftRfpHtml($rfp);
        $this->html .= '</div>';

        $this->html .= '<div class="item-panel-right">';
        $this->addRightRfpHtml($rfp);
        $this->html .= '</div>';

        $this->html .= '<div class="clear"></div>';

        $this->html .= '</div>';
    }

    private function addRightRfpHtml($rfp) {
        $this->html .= '<div class="date-item">';

        $this->html .= '<span>'
            . date('Y-m-d', floor($rfp->activationTime / 1000)) . OferteoApiDict::get($this->locale, 'rfp.search.rfp.fromTo') . date('Y-m-d', floor($rfp->expirationTime / 1000))
            . '</span>';

        if ($rfp->active) {
            $this->html .= '<br/>';

            if ($this->sort == OferteoApi::DEFAULT_SORT) {
                $this->html .= OferteoApiDict::get($this->locale, 'rfp.details.date.added') . $rfp->activationPeriod;
            } else {
                $this->html .= OferteoApiDict::get($this->locale, 'rfp.details.date.valid.to') . '<span class="' . $rfp->expirationPeriodStyle . '">' . $rfp->expirationPeriod . '</span>';
            }
        } else {
            $this->html .= '<br/>'
                . '<span class="' . $rfp->expirationPeriodStyle . '">'
                . $rfp->expirationPeriod
                . '</span>';
        }

        $this->html .= '</div>';

        $this->html .= '<div class="clear"></div>';
    }

    private function addLeftRfpHtml($rfp) {
        $this->html .= '<div class="' . $this->getIconClass($rfp) . '" title="' . $this->getRfpIconTitle($rfp) . '"></div>';

        $this->html .= '<a href="' . $this->urlPrefix . '/' . $rfp->rfpUrl . '" title="' . $rfp->title . '">'
            . $rfp->title . '</a>';

        $this->html .= '<div class="clear"></div>';

        $this->html .= '<div class="text-item">'
            . OferteoApiUtils::getShortedText($rfp->description, 230) . '...'
            . '</div>';

        $this->addCategoryAndLocation($rfp);
    }

    public function addCategoryAndLocation($rfp) {
        $this->html .= '<div class="category-item">';

        $this->html .= '<div class="tags-item">';
        $categoryUrl = $this->urlPrefix . $rfp->categoryUrl . ($this->selectedLocationUrl ? $this->selectedLocationUrl : '');
        $this->html .= '<a href="' . $categoryUrl . '" title="' . $rfp->categoryName . '" class="link">'
            . $rfp->categoryName . '</a>';
        $this->html .= '</div>';

        $this->html .= '<div class="location-item">';
        if ($rfp->dstVoivodship) {
            $url = $this->urlPrefix
                . ($this->selectedCategoryUrl ? $this->selectedCategoryUrl : '')
                . $rfp->dstVoivodshipUrl;
            $title = ($this->rfpSearchResult->selectedCategoryName ? $this->rfpSearchResult->selectedCategoryName : '')
                . ' ' . $rfp->dstVoivodship;
            $this->html .= '<a href="' . $url . '" title="' . $title . '" class="link">'
                . $rfp->dstVoivodship . '</a>';

            $this->html .= $rfp->dstCity ? ' / ' : '';
        }
        $this->html .= $rfp->dstCity;
        $this->html .= '</div>';

        $this->html .= '<div class="clear"></div>';

        $this->html .= '</div>';
    }

    public function getIconClass($rfp) {
        if ($rfp->individual) {
            if ($rfp->active) {
                return "icon-individual-person pngfix icon-individual-person-active";
            } else {
                return "icon-individual-person pngfix icon-individual-person-inactive";
            }
        } else {
            if ($rfp->active) {
                return "icon-company pngfix icon-company-active";
            } else {
                return "icon-company pngfix icon-company-inactive";
            }
        }
    }

    public function getRfpIconTitle($rfp) {
        if ($rfp->active) {
            if ($rfp->individual) {
                $key = "rfp.title.personal.active";
            } else {
                $key = "rfp.title.company.active";
            }
        } else {
            if ($rfp->individual) {
                $key = "rfp.title.personal.inactive";
            } else {
                $key = "rfp.title.company.inactive";
            }
        }
        return OferteoApiDict::get($this->locale, $key);
    }

    private function getPaginationAndSortHtml() {
        $pagerFromUrl = OferteoApiUtils::findPagerInUrl($this->urlCurrent);

        if ($pagerFromUrl < 0) {
            $pagerFromUrl = 1;
        }

        $pages = 1;

        if ($this->rfpSearchResult->rfpsCounter > $this->pageSize) {
            $pages = ceil($this->rfpSearchResult->rfpsCounter / $this->pageSize);
        }

        $this->html .= '<div class="pagination-sort-box">';

        $this->addPagination($pages, $pagerFromUrl);

        $this->addSortBox();

        $this->html .= '</div>';
    }

    private function addPagination($pages, $currentPage) {
        $this->html .= '<div class="pagination-item">';

        $sort = OferteoApiUtils::getSortFromUrl($this->urlQueryString);
        $sortParam = $sort == OferteoApi::DEFAULT_SORT ? '' : '?sort=' . $sort;

        $prevPage = $currentPage - 1;
        if ($prevPage > 0) {
            $this->html .= '<a class="arrow-all-next" href="' . $this->getUrlCurrentSelection() . '/1' . $sortParam . '"></a>';
            $this->html .= '<a class="arrow-next" href="' . $this->getUrlCurrentSelection() . '/' .$prevPage . $sortParam . '"></a>';
        }

        $maxPages = 10;
        $firstVisiblePage = 1;
        $lastVisiblePage = $pages;

        if ($pages > $maxPages) {
            $firstVisiblePage = max(1, $currentPage - ($maxPages / 2));
            $lastVisiblePage = min($pages, $firstVisiblePage + $maxPages);
        }

        for ($i = $firstVisiblePage; $i <= $lastVisiblePage; $i++) {
            if ($i == $currentPage) {
                $this->html .= '<span>' . $i . '</span>';
            } else {
                $this->html .= '<a href="' . $this->getUrlCurrentSelection() . '/' . $i . $sortParam .'">' . $i . '</a>';
            }
        }

        $nextPage = $currentPage + 1;
        if ($nextPage <= $pages) {
            $this->html .= '<a class="arrow-all-back" href="' . $this->getUrlCurrentSelection() . '/' . $nextPage
                . $sortParam . '"></a>';
            $this->html .= '<a class="arrow-back" href="' . $this->getUrlCurrentSelection() . '/' . $pages
                . $sortParam . '"></a>';
        }

        $this->html .= '<div class="page-number">' .OferteoApiDict::get($this->locale, 'rfp.search.results.currentPage') . $currentPage . ' z ' . $pages . '</div>';

        $this->html .= '</div>';
    }

}